summaryrefslogtreecommitdiffstats
path: root/certmanager/lib/ui/dnattributeorderconfigwidget.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit36a36a5c1015aa0d03f4515c401e907ddb9d6291 (patch)
tree0212ba6d2c749043134005a41f2bd0379619d40f /certmanager/lib/ui/dnattributeorderconfigwidget.h
parent4c6f8d69e2d1501837affb472c4eb8fec4462240 (diff)
downloadtdepim-36a36a5c1015aa0d03f4515c401e907ddb9d6291.tar.gz
tdepim-36a36a5c1015aa0d03f4515c401e907ddb9d6291.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'certmanager/lib/ui/dnattributeorderconfigwidget.h')
-rw-r--r--certmanager/lib/ui/dnattributeorderconfigwidget.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/certmanager/lib/ui/dnattributeorderconfigwidget.h b/certmanager/lib/ui/dnattributeorderconfigwidget.h
index a0867c4fa..b433c35ba 100644
--- a/certmanager/lib/ui/dnattributeorderconfigwidget.h
+++ b/certmanager/lib/ui/dnattributeorderconfigwidget.h
@@ -47,8 +47,8 @@ namespace Kleo {
Q_OBJECT
TQ_OBJECT
public:
- /*! Use Kleo::DNAttributeMapper::instance()->configWidget( tqparent, name ) instead. */
- DNAttributeOrderConfigWidget( DNAttributeMapper * mapper, TQWidget * tqparent=0, const char * name=0, WFlags f=0 );
+ /*! Use Kleo::DNAttributeMapper::instance()->configWidget( parent, name ) instead. */
+ DNAttributeOrderConfigWidget( DNAttributeMapper * mapper, TQWidget * parent=0, const char * name=0, WFlags f=0 );
~DNAttributeOrderConfigWidget();
void load();